@@ -11,10 +11,17 @@
 #' (see `?xml2::read_html`).
 
 safely_read_html <- function(url, ...) {
-  do_safely_read_html <- purrr::safely(xml2::read_html)
+
+  dl_and_read <- function(url, ...) {
+    dl_file(url = url,
+            destfile = tempfile()) %>%
+      xml2::read_html(...)
+  }
+
+  do_safely_read_html <- purrr::safely(dl_and_read)
 
   x <- do_safely_read_html(
-    x = url,
+    url,
     ...,
     user_agent = "readrba R package - https://mattcowgill.github.io/readrba/index.html"
   )
@@ -24,7 +31,7 @@ safely_read_html <- function(url, ...) {
     # Try again with a delay with scraping failed the first time
     Sys.sleep(5)
     x <- do_safely_read_html(
-      x = url,
+      url,
       ...,
       user_agent = "readrba R package - https://mattcowgill.github.io/readrba/index.html"
     )
